{
	"name" : "Human Resources Evaluation",
	"version" : "0.1",
	"author" : "Tiny",
	"category" : "Generic Modules/Human Resources",
	"website" : "http://tinyerp.com/module_hr.html",
	"depends" : ["hr"],
	"description": "Ability to create employees evaluation.",
	"init_xml" : [],
	"demo_xml" : ["hr_evaluation_demo.xml"],
	"update_xml" : ["hr_evaluation_view.xml"],
	"active": False,
	"installable": False
}
